#!/bin/bash
# administrarUsuarios.sh
# Script para la administración de usuarios

function uso
{
	echo "Uso:"
	echo "Añadir un nuevo usuario"
	echo "$0 -adduser usuario password"
	echo
	echo "Eliminar un usuario"
	echo "$0 -deluser usuario"
	echo
	echo "Establecer la shell por defecto para el usuario"
	echo "$0 -shell usuario SHELL_PATH"
	echo
	echo "Deshabilitar una cuenta de usuario"
	echo "$0 -disable usuario"
	echo
	echo "Activar una cuenta de usuario deshabilitada"
	echo "$0 -enable usuario"
	echo
	echo "Asignar fecha de expiración de la cuenta"
	echo "$0 -expiry FECHA"
	echo
	echo "Cambiar la contraseña"
	echo "$0 -passwd usuario"
	echo
	echo "Crear un nuevo grupo de usuarios"
	echo "$0 -newgroup grupo"
	echo
	echo "Eliminar un grupo"
	echo "$0 -delgroup grupo"
	echo
	echo "Añadir un usuario al grupo"
	echo "$0 -addgroup usuario grupo"
	echo
	echo "Mostrar información detallada del usuario"
	echo "$0 -details usuario"
	echo
	echo "Mostrar ayuda"
	echo "$0 -usage"
	echo
	exit
}

# Debe ejecutarse en modo root
if [ $UID -ne 0 ]; then
	echo "Debe ejecutar $0 como Root."
	exit 2
fi

case $1 in
	-adduser) [ $# -ne 3 ] && usage ; useradd $2 -p $3 -m ;;
	-deluser) [ $# -ne 2 ] && usage ; deluser $2 --remove-all-files;;
	-shell) [ $# -ne 3 ] && usage ; chsh $2 -s $3 ;;
	-disable) [ $# -ne 2 ] && usage ; usermod -L $2 ;;
	-enable) [ $# -ne 2 ] && usage ; usermod -U $2 ;;
	-expiry) [ $# -ne 3 ] && usage ; chage $2 -E $3 ;;
	-passwd) [ $# -ne 2 ] && usage ; passwd $2 ;;
	-newgroup) [ $# -ne 2 ] && usage ; addgroup $2 ;;
	-delgroup) [ $# -ne 2 ] && usage ; delgroup $2 ;;
	-addgroup) [ $# -ne 3 ] && usage ; addgroup $2 $3 ;;
	-details) [ $# -ne 2 ] && usage ; finger $2 ; chage -l $2 ;;
	-usage) uso ;;
	*) uso ;;
esac

