#!/bin/bash
# gfpt.sh

#********************************************************************************
# Script para enviar ficheros por FTP de manera automatizada
#
# Nota: Es mejor usar "expect" pero no todas las maquinas lo tienen instalado.
# Esta solución funciona con cualquier intérprete de bash.
#
# IMPORTANTE: En el directorio donde se generen los ficheros temporales, el usuario
# debe tener permisos de escritura.
#
#*******************************************************************************

# Variables preconfiguradas. Sustituya aquí los valores de su servidor FTP.

host='servidorFTP'
usuario='usuario'
password='password'
path=/
ftpfile=ftp.temp


#-------------------------------------------------------------
# @genera_ftp_script
#
# Genera un script FTP para transferir los archivos indicados.
#
# @param El fichero o La lista de ficheros a transferir
# @param el directorio destino dentro del ftp server
#-------------------------------------------------------------
function genera_ftp_script
{
    # Ver la lista de ficheros que se reciben como parámetro
    for i in $1; do
            echo item: $i
    done

    data=$1
    echo "Recibido: $data"

    echo "#!/bin/bash" > $ftpfile
    echo "ftp -n -iv $host <<EOF" >>$ftpfile
    echo "user $usuario $password" >> $ftpfile
    echo "binary" >> $ftpfile
    echo "hash" >> $ftpfile
    echo "cd $2" >> $ftpfile
    echo "mput \"$1\"" >> $ftpfile
    echo "bye" >> $ftpfile
    echo "EOF" >> $ftpfile
    return "0"
}
#---

#-----------
# PRINCIPAL
#-----------

# Chequear los parámetros recibidos
if [ "${1}" ]; then
    continue=0
else
    echo ""
    echo "Mueve los ficheros indicados a un servidor FTP predeterminado (variables internas en el script)"
    echo "Sintaxis: $0 [fichero|Lista de ficheros] [Directorio_destino]"
    echo "Ejemplo: $0 \"*.mp3\" MUSICA"
    echo "(Si se usan ficheros con patrones recursivos * el párametro debe ir encerrado entre comillas simples. Ejemplo: \"cat*.txt\" )"
    echo ""
    echo "ERROR: No se ha especificado ningún parámetro. No se enviará por FTP ningún archivo."
    echo ""
    exit
fi

# Comprobar si se indicó alguna ruta destino. Si no se indica ninguna, por defecto se usa "/"
if [ "x${2}" == "x" ]; then
 path="/"
else
 path=$2
 continue=0
fi

# Transferir por FTP los ficheros indicados
genera_ftp_script "$1" "$path"

# Se da permiso de ejecución al script FTP de transferencia creado y se ejecuta
chmod +x $ftpfile
resultado=`./$ftpfile` 

# Imprimir resultados de la transferencia FTP
echo ""
echo "-- Respuesta FTP --"
echo $resultado
echo "-- Fin FTP --"
echo ""

# Borrar los ficheros temporales generados
rm $ftpfile 

