#!/bin/bash
# backupMail.sh 
#
# Realiza una copia de seguridad de los ficheros indicados en el archivo
# ~/.mybackup, lo comprime en formato .tar.gz y
# lo envía por correo electrónico

# Indique en ese archivo los ficheros/directorios a salvaguardar
#
# Uso   : ./backupMail
#

 
FICHERO=~/.mybackup
FECHA=`date +"%d-%m-%Y"`
FORMATO="`echo $USER.$HOSTNAME`.$FECHA.tar.gz"
TAR=`which tar`
 
# Configuración del correo
DESTINATARIO="usuario@dominio.com"
ASUNTO="Backup (`echo $USER @ $HOSTNAME`) en `date`"
MENSAJE=~/tmp/mybackup.txt
MATT=~/tmp/$FORMATO
 
# Los datos se almacenan en su directorio tmp y no en  /tmp
[ ! -d ~/tmp ] && mkdir ~/tmp || :
if [ -f $FICHERO ]; then
	IN="`cat $FICHERO | grep -E -v "^#"`"
else
	echo "$FICHERO no existe"
	exit 3
fi
 
if [ "$IN" == "" ]; then
	echo "$FICHERO está vacío"
	echo "Por favor, añada ficheros/directorios a copiar en el backup"
	exit 2
fi
 
$TAR -zcf ~/tmp/$FORMATO $IN >/dev/null

# Creación del mensaje de correo
echo "Backup realizado con éxito. Por favor, vea el documento adjunto." > $MENSAJE
echo "" >> $MENSAJE
echo "Backup: $FORMATO" >> $MENSAJE
echo "" >> $MENSAJE
 
# Sólo se pueden enviar adjuntos si tiene mutt instalado
which mutt > /dev/null
if [ $? -eq 0 ]; then
	# Enviar el fichero con el backup adjunto
	mutt -s "$ASUNTO" -a "$MATT" $DESTINATARIO < $MENSAJE
else
	echo "mutt no se encuentra en el sistema"
	echo "No se puede enviar el fichero adjunto"
fi
 
# Borrar ficheros temporales
/bin/rm -f $MATT
/bin/rm -f $MENSAJE

