#!/bin/bash
# secureBackup.sh
#
# Realiza un backup del directorio indicado a un servidor FTP remoto, 
# subiendo la información de forma segura, para lo cual usa gpg con
# el propósito de encriptar el fichero .tar.gz resultante antes de 
# enviarlo.
#
# Para su correcta ejecución debe tener instalado:
# - /usr/bin/ncftpput
# - /bin/tar
# - /usr/bin/mail
# - /usr/bin/gpg
#
# El script manda un correo de confirmación al administrador
# informando del éxito o fracaso del proceso
#
# Instalación:
# Personalice el script de acuerdo a sus parámetros de configuración
# indicando el servidor FTP, usuario, contraseña, etc
#
# Deberá generar las claves gpg para su usuario e importar la clave pública
# de cara a la encriptación de los ficheros. 

# PARÁMETROS DE CONFIGURACIÓN

# Directorios a copiar (puede indicar varios separándolos con espacios)
BACKUP="/home"
 
# Servidor FTP
FTPH="servidor"
 
# Usuario FTP
FTPU="ftpusername"
 
# Password FTP
FTPP="secreta"
 
# gpg userID
GPGU="gpguserID"
 
# Directorio remoto, blanco para directorio por defecto
# Si no existe será creado automáticamente por ncftpput 
# Asegúrese de tener los permisos necesarios para ello
FTPD="backup/"
 
# Directorio temporal para almacenar el fichero tar.gz y procesarlo
TMPD="/tmp"
 
# Email del administrador
MTO="admin@mail.com"
# Asunto
MSUB="Informe de Backup de $(hostname)"
# Información de administrador
ADMIN_INFO="Para contactar con el administrador: admin@mail.com"
 
# Ubicación de los binarios
NCFTP="/usr/bin/ncftpput"
TAR="/bin/tar"  
MAILC="/usr/bin/mail"
GPG="/usr/bin/gpg"
 
#######################################################################
# NO CAMBIE NADA DE ABAJO
#######################################################################
FILE="$(hostname).$(date +"%d-%m-%Y").tar.gz"
OUT="$TMPD/$FILE"
FOUT="$OUT.gpg"
MFILE="/tmp/ftpout.$$.txt"
MESS=""
 
if [ ! -x $TAR ]; then
  echo "$TAR comando no encontrado, $ADMIN_INFO"
  exit 1
fi
 
if [ ! -x $NCFTP ]; then
  echo "$NCFTP comando no encontrado, $ADMIN_INFO"
  exit 1
fi
 
if [ ! -x $GPG ] ; then
  echo "$GPG comando no encontrado, $ADMIN_INFO"
  exit 1
fi
 
$TAR -zcf $OUT $BACKUP
if [ $? -ne 0 ]; then
   MESS="$TAR falló al crear el fichero. No se enviará nada al servidor FTP $FTPH"
else
   # Encriptar el fichero .tar.gz antes de su envío
   $GPG -e -r $GPGU -o $FOUT $OUT
   $NCFTP -m -u "$FTPU" -p "$FTPP" "$FTPH" "$FTPD" "$FOUT"
   OSTAT="$?"
   case $OSTAT in
        0) MESS="OK.";;
        1) MESS="Imposible conectar al servidor remoto $FTPH.";;
        2) MESS="Imposible conectar al servidor remoto $FTPH - timed out.";;
        3) MESS="Fallo en la transferencia.";;
        4) MESS="Fallo en la transferencia - timed out.";;
        5) MESS="Fallo al cambiar de directorio.";;
        6) MESS="Fallo al cambiar de directorio - timed out.";;
        7) MESS="URL incorrecta.";;
        8) MESS="Error de uso. Actualice su versión de ncftpput ($NCFTP)";;
        9) MESS="Error en el archivo de configuración.";;
        10)MESS="Inicialización incorrecta de librerias.";;
        11) MESS="Fallo en el inicio de sesión.";;
        *) MESS="Error desconocido, $ADMIN_INFO";;
   esac
fi
 
>$MFILE
echo "Estado de Backup de $(hostname) en $(date):" >>$MFILE
echo "" >>$MFILE
echo "Fichero de Backup : $FOUT" >>$MFILE
echo "Servidor FTP : $FTPH" >>$MFILE
echo "Estado del Backup : $MESS" >>$MFILE
echo "" >>$MFILE
echo "-- Generado automáticamente por $(basename $0)" >>$MFILE
 
# Envío de mail al administrador
$MAILC -s "$MSUB" $MTO <$MFILE
# Eliminación de archivos temporales
[ -f $MFILE ] && rm -f $MFILE || :
[ -f $FOUT ] && rm -f $FOUT || :
[ -f $OUT ] && rm -f $OUT || :

